==> pulsar-client-all-3.1.0-sources.jar: org/apache/pulsar/shade/javax/ws/rs/ProcessingException.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2015 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.apache.pulsar.shade.javax.ws.rs;

/**
 * A base JAX-RS runtime processing exception.
 *
 * The exception of this type is thrown during HTTP request or response processing,
 * to signal a runtime processing failure. Typical classes of failures covered by
 * {@code ProcessingException} include
 * <ul>
 * <li>failures in filter or interceptor chain execution,</li>
 * <li>errors caused by missing message body readers or writers for the particular Java type
 * and media type combinations,</li>
 * <li>propagated {@link java.io.IOException IO exceptions} thrown by
 * entity {@link org.apache.pulsar.shade.javax.ws.rs.ext.MessageBodyReader readers} and {@link org.apache.pulsar.shade.javax.ws.rs.ext.MessageBodyWriter writers}
 * during entity serialization and de-serialization.</li>
 * </ul>
 * as well as any other JAX-RS runtime processing errors.
 * The exception message or nested {@link Throwable}
 * cause SHOULD contain additional information about the reason of the processing
 * failure.
 * <p>
 * Note that the exception is used to indicate (internal) JAX-RS processing errors.
 * It is not used to indicate HTTP error response states. A HTTP error response is
 * represented by a {@link org.apache.pulsar.shade.javax.ws.rs.WebApplicationException} class or one of it's
 * sub-classes.
 * </p>
 *
 * @author Marek Potociar
 * @since 2.0
 */
public class ProcessingException extends RuntimeException {

    private static final long serialVersionUID = -4232431597816056514L;

    /**
     * Constructs a new JAX-RS runtime processing exception with the specified cause
     * and a detail message of {@code (cause==null ? null : cause.toString())}
     * (which typically contains the class and detail message of {@code cause}).
     * This constructor is useful for runtime exceptions that are little more
     * than wrappers for other throwables.
     *
     * @param cause the cause (which is saved for later retrieval by the
     *              {@link #getCause()} method). (A {@code null} value is permitted,
     *              and indicates that the cause is nonexistent or unknown.)
     */
    public ProcessingException(final Throwable cause) {
        super(cause);
    }

    /**
     * Constructs a new JAX-RS runtime processing exception with the specified detail
     * message and cause.
     * <p/>
     * Note that the detail message associated with {@code cause} is <i>not</i>
     * automatically incorporated in this runtime exception's detail message.
     *
     * @param message the detail message (which is saved for later retrieval
     *                by the {@link #getMessage()} method).
     * @param cause   the cause (which is saved for later retrieval by the
     *                {@link #getCause()} method). (A {@code null} value is permitted,
     *                and indicates that the cause is nonexistent or unknown.)
     */
    public ProcessingException(final String message, final Throwable cause) {
        super(message, cause);
    }

    /**
     * Constructs a new JAX-RS runtime processing exception with the specified detail
     * message. The cause is not initialized, and may subsequently be initialized
     * by a call to {@link #initCause}.
     *
     * @param message the detail message (which is saved for later retrieval
     *                by the {@link #getMessage()} method).
     */
    public ProcessingException(final String message) {
        super(message);
    }
}

==> pulsar-client-all-3.3.5-sources.jar: org/apache/pulsar/shade/javax/ws/rs/ProcessingException.java <==
/*
 * Copyright (c) 2011, 2017 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.apache.pulsar.shade.javax.ws.rs;

/**
 * A base runtime processing exception.
 *
 * The exception of this type is thrown during HTTP request or response processing,
 * to signal a runtime processing failure. Typical classes of failures covered by
 * {@code ProcessingException} include
 * <ul>
 * <li>failures in filter or interceptor chain execution,</li>
 * <li>errors caused by missing message body readers or writers for the particular Java type
 * and media type combinations,</li>
 * <li>propagated {@link java.io.IOException IO exceptions} thrown by
 * entity {@link org.apache.pulsar.shade.javax.ws.rs.ext.MessageBodyReader readers} and {@link org.apache.pulsar.shade.javax.ws.rs.ext.MessageBodyWriter writers}
 * during entity serialization and de-serialization.</li>
 * </ul>
 * as well as any other runtime processing errors.
 * The exception message or nested {@link Throwable}
 * cause SHOULD contain additional information about the reason of the processing
 * failure.
 * <p>
 * Note that the exception is used to indicate (internal) processing errors.
 * It is not used to indicate HTTP error response states. A HTTP error response is
 * represented by a {@link org.apache.pulsar.shade.javax.ws.rs.WebApplicationException} class or one of it's
 * sub-classes.
 * </p>
 *
 * @author Marek Potociar
 * @since 2.0
 */
public class ProcessingException extends RuntimeException {

    private static final long serialVersionUID = -4232431597816056514L;

    /**
     * Constructs a new runtime processing exception with the specified cause
     * and a detail message of {@code (cause==null ? null : cause.toString())}
     * (which typically contains the class and detail message of {@code cause}).
     * This constructor is useful for runtime exceptions that are little more
     * than wrappers for other throwables.
     *
     * @param cause the cause (which is saved for later retrieval by the
     *              {@link #getCause()} method). (A {@code null} value is permitted,
     *              and indicates that the cause is nonexistent or unknown.)
     */
    public ProcessingException(final Throwable cause) {
        super(cause);
    }

    /**
     * Constructs a new runtime processing exception with the specified detail
     * message and cause.
     * <p/>
     * Note that the detail message associated with {@code cause} is <i>not</i>
     * automatically incorporated in this runtime exception's detail message.
     *
     * @param message the detail message (which is saved for later retrieval
     *                by the {@link #getMessage()} method).
     * @param cause   the cause (which is saved for later retrieval by the
     *                {@link #getCause()} method). (A {@code null} value is permitted,
     *                and indicates that the cause is nonexistent or unknown.)
     */
    public ProcessingException(final String message, final Throwable cause) {
        super(message, cause);
    }

    /**
     * Constructs a new runtime processing exception with the specified detail
     * message. The cause is not initialized, and may subsequently be initialized
     * by a call to {@link #initCause}.
     *
     * @param message the detail message (which is saved for later retrieval
     *                by the {@link #getMessage()} method).
     */
    public ProcessingException(final String message) {
        super(message);
    }
}
